@@ -11,8 +11,20 @@ from django.core.exceptions import ValidationError
 
 from filebrowser.fields import FileBrowseField
 
-#from ckeditor.fields import RichTextField
-from djangocms_text_ckeditor.fields import HTMLField
+# Try to find a django app for the CKeditor, else fallback on TextField
+try:
+    from djangocms_text_ckeditor.fields import HTMLField
+except ImportError:
+    # djangocms_text_ckeditor is not installed
+    try:
+        from ckeditor.fields import RichTextField
+    except ImportError:
+        # None of ckeditor app is installed
+        CkeditorField = models.TextField
+    else:
+        CkeditorField = RichTextField
+else:
+    CkeditorField = HTMLField
 
 PUBLISHED_CHOICES = (
     (True, _('Published')),
@@ -63,8 +75,7 @@ class Slide(models.Model):
     title = models.CharField(_('title'), blank=False, max_length=255)
     priority = models.IntegerField(_('display priority'), default=100, help_text=_('Priority display value'))
     publish = models.BooleanField(_('published'), choices=PUBLISHED_CHOICES, default=True, help_text=_('Unpublished slide will not be displayed in its slideshow'))
-    #content = RichTextField(_("content"), blank=True)
-    content = HTMLField(_("content"), blank=True)
+    content = CkeditorField(_("content"), blank=True)
     image = FileBrowseField(_('image'), max_length=255, null=True, blank=True, default=None)
     url = models.CharField(_('url'), blank=True, max_length=255, help_text=_('An URL that can be used in the template for this entry'))
     open_blank = models.BooleanField(_('open new window'), default=False, help_text=_('If checked the link will be open in a new window'))
